﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Phidgets;
using Phidgets.Events;
using NetworkItWPF;

namespace ComputerTouch
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {

        // Server stuff
        Client client;
        String user = "Aaron";

        // Ring stuff
        public InterfaceKit inputKit = new InterfaceKit();

        int iIndex1 = -1;
        int iIndex2 = -1;

        double dTime1 = DateTime.Now.TimeOfDay.TotalMilliseconds;
        double dTime2 = DateTime.Now.TimeOfDay.TotalMilliseconds;

        bool bPlaying = true;

        public MainWindow()
        {
            InitializeComponent();

            this.client = new Client(user, "581.cpsc.ucalgary.ca", 8000);

            this.inputKit.Attach += inputKit_Attach;
            this.inputKit.open();
        }

        void inputKit_Attach(object sender, AttachEventArgs e)
        {
            this.inputKit.InputChange += inputKit_InputChange;
        }

        void inputKit_InputChange(object sender, InputChangeEventArgs e)
        {
            if (e.Value == true)
            {
                iIndex2 = iIndex1;
                iIndex1 = e.Index;

                dTime2 = dTime1;
                dTime1 = DateTime.Now.TimeOfDay.TotalMilliseconds;

                // Check if our input sequence is an event
                if (iIndex2 != -1)
                    CheckInputs();

            }
            else
            {
                if ((e.Index == iIndex1) && ((DateTime.Now.TimeOfDay.TotalMilliseconds - dTime1) >= 1000))
                {
                    if (bPlaying)
                    {
                        Pause();
                        bPlaying = false;
                    }
                    else
                    {
                        Play();
                        bPlaying = true;
                    }

                    ResetInputs();
                }
            }
        }

        void CheckInputs()
        {
            if (((dTime1 - dTime2) <= 500) && ((dTime1 - dTime2) >= 100))
            {
                if (iIndex1 == (iIndex2 + 1))
                {
                    NextSong();

                    ResetInputs();
                }
                else if (iIndex1 == (iIndex2 - 1))
                {
                    PreviousSong();

                    ResetInputs();
                }
                else if ((iIndex1 == 2) && ( iIndex2 == 2 ))
                {
                    VolUp();

                    ResetInputs();
                }
                else if ((iIndex1 == 0) && (iIndex2 == 0))
                {
                    VolDown();

                    ResetInputs();
                }
            }
        }

        void ResetInputs()
        {
            iIndex1 = -1;
            iIndex2 = -1;
        }

        void NextSong()
        {
            SendNewMessage("NextSong");
        }

        void PreviousSong()
        {
            SendNewMessage("PreviousSong");
        }

        void VolUp()
        {
            SendNewMessage("VolUp");
        }

        void VolDown()
        {
            SendNewMessage("VolDown");
        }

        void Pause()
        {
            SendNewMessage("PauseSong");
        }

        void Play()
        {
            SendNewMessage("PlaySong");
        }

        void SendNewMessage( string sName )
        {
            // Create a message and populate it
            Message message = new Message(sName);

            // Send the message
            this.client.SendMessage(message);
        }

        private void PlayButton_Click(object sender, RoutedEventArgs e)
        {
            Play();
        }

        private void PauseButton_Click(object sender, RoutedEventArgs e)
        {
            Pause();
        }

        private void NextSongButton_Click(object sender, RoutedEventArgs e)
        {
            NextSong();
        }

        private void PrevSongButton_Click(object sender, RoutedEventArgs e)
        {
            PreviousSong();
        }

        private void VolUpButton_Click(object sender, RoutedEventArgs e)
        {
            VolUp();
        }

        private void VolDownButton_Click(object sender, RoutedEventArgs e)
        {
            VolDown();
        }
    }
}
